<?php

namespace Drupal\intense;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides re-usable admin functions, or form elements.
 */
class IntenseAdmin implements IntenseAdminInterface {

  use StringTranslationTrait;

  /**
   * Defines re-usable form elements.
   */
  public function buildSettingsForm(array &$element, $definition = []) {
    $settings     = $definition['settings'];
    $image_styles = image_style_options(FALSE);

    if (isset($element['media_switch'])) {
      $element['media_switch']['#options']['intense'] = $this->t('Image to Intense');
    }

    $element['intense_header'] = [
      '#type'   => 'item',
      '#markup' => '<h3 class="form__title">' . $this->t('Intense image integration') . '</h3>',
      '#weight' => -90,
      '#access' => isset($settings['optionset']),
    ];

    $element['intense_style'] = [
      '#title'         => $this->t('Intense image style'),
      '#type'          => 'select',
      '#default_value' => $settings['intense_style'],
      '#options'       => $image_styles,
      '#empty_option'  => $this->t('None (original image)'),
      '#description'   => $this->t('The fullscreen image style. Be sure the image is large enough for a fullscreen. Leave empty to use original image.'),
      '#weight'        => -90,
    ];

    $element['intense_icon'] = [
      '#title'         => $this->t('Use Intense icon'),
      '#type'          => 'checkbox',
      '#default_value' => $settings['intense_icon'],
      '#description'   => $this->t('If checked, the provided Intense icon will act as the trigger. Otherwise the image itself. Useful to avoid issue with draggable slider, etc.'),
      '#weight'        => -90,
    ];

    $element['intense_caption'] = [
      '#title'         => $this->t('Use Intense caption'),
      '#type'          => 'checkbox',
      '#default_value' => isset($settings['intense_caption']) ? $settings['intense_caption'] : FALSE,
      '#description'   => $this->t('If checked, the selected captions will also be displayed as part of Intense fullscreen images.'),
      '#weight'        => -90,
      '#access'        => isset($settings['optionset']),
    ];

    $element['#attached']['library'][] = 'intense/admin';
  }

}
